@@ -2,7 +2,7 @@
 # Imports
 import os
 import time
-from typing import Callable
+from collections.abc import Callable
 
 import stouputils as stp
 
@@ -13,6 +13,7 @@ os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 from .compatibilities.main import main as compatibilities_main
 from .datapack.main import main as datapack_main
 from .datapack.recipes import main as recipes_main
+from .debug_info import main as debug_info_main
 from .enhance_config import main as enhance_config_main
 from .finalyze import main as finalyze_main
 from .initialize import main as initialize_main
@@ -24,7 +25,7 @@ from .verify_database import main as verify_database_main
 # Functions
 def basic_key_check(config: dict, key: str, value_type: type, hint: str, valid: bool) -> bool:
 	bool_return = valid
-	if config.get(key, None) == None:
+	if config.get(key, None) is None:
 		bool_return = stp.warning(f"Missing '{key}' key in config file\n ({hint})") or False
 	elif not isinstance(config[key], value_type):
 		bool_return = stp.warning(f"Invalid type for '{key}' key in config file, found {type(config[key])} instead of {value_type}\n ({hint})") or False
@@ -39,7 +40,7 @@ def check_config_format(config: dict) -> bool:
 	valid = basic_key_check(config, "version", str, "Datapack version in the following mandatory format: major.minor.patch, ex: 1.0.0 or 1.21.615", valid)
 	valid = basic_key_check(config, "namespace", str, "Used to namespace functions, tags, etc. Should be the same you use in the merge folder.", valid)
 	valid = basic_key_check(config, "description", str, "Pack description displayed in pack.mcmeta", valid)
-	if config.get("ignore_unset", None) == True:
+	if config.get("ignore_unset", None) is True:
 		return valid
 	valid = basic_key_check(config, "merge_folder", str, "If a file exists in both merge and build folder, they will be merged. Otherwise, it's just copied.", valid)
 	valid = basic_key_check(config, "assets_folder", str, "Folder containing the all assets (textures, sounds, ...) for the datapack", valid)
@@ -52,9 +53,9 @@ def check_config_format(config: dict) -> bool:
 	valid = basic_key_check(config, "dependencies", dict, "Automagically, the datapack will check for the presence of dependencies and their minimum required versions at runtime\nThe url is used when the dependency is not found to suggest where to get it\nThe version dict key contains the minimum required version of the dependency in [major, minor, patch] format\nThe main key is the dependency namespace to check for\nThe name can be whatever you want, it's just used in messages", valid)
 	valid = basic_key_check(config, "source_lore", list, "Appended lore to any custom item, can be an empty string to disable", valid)
 	has_manual: bool|None = config.get("has_manual", None)
-	if has_manual != None:
+	if has_manual is not None:
 		valid = basic_key_check(config, "has_manual", bool, "Do the program generate a manual/guide? (WARNING: if an item is malformed in the database, the server log will be flooded on load by the manual hiding the malformed item)", True)
-	if has_manual == True:
+	if has_manual is True:
 		valid = basic_key_check(config, "manual_path", str, "Cached manual assets", valid)
 		valid = basic_key_check(config, "manual_overrides", str, "Path to a folder containing manual overrides to replace the default manual assets", valid)
 		valid = basic_key_check(config, "manual_high_resolution", bool, "Enable the high resolution for the manual to increase the craft resolutions", valid)
@@ -66,11 +67,11 @@ def check_config_format(config: dict) -> bool:
 		valid = basic_key_check(config, "max_rows_per_page", int, "Max number of rows per page in the manual, should not exceed 6", valid)
 		valid = basic_key_check(config, "opengl_resolution", int, "Resolution of the OpenGL renders used in the manual, best value is 256 <--- 256x256", valid)
 		valid = basic_key_check(config, "manual_first_page_text", list, "Text for the first page of the manual", valid)
-	if valid == True:
+	if valid is True:
 		for key in config.keys():
 			if key not in KNOWN_KEYS:
 				stp.warning(f"Unknown key '{key}' in config file, it might be a typo or been removed from the configuration")
-	return valid == True
+	return valid is True
 
 
 def build_process(config: dict, setup_database: Callable|None = None, setup_external_database: Callable|None = None, user_code: Callable|None = None):
@@ -88,11 +89,11 @@ def build_process(config: dict, setup_database: Callable|None = None, setup_exte
 	valid = check_config_format(config)
 	if not valid:
 		stp.error("Invalid config format, please check the documentation")
-	
+
 	# Enhance config dict
 	config = enhance_config_main(config)
 
-	# Get start time & 
+	# Get start time &
 	START_TIME: float = time.perf_counter()
 	stp.info("Starting build process...")
 
@@ -108,6 +109,9 @@ def build_process(config: dict, setup_database: Callable|None = None, setup_exte
 		if config.get("database"):
 			verify_database_main(config)
 
+		# Prepare debug info
+		debug_info_main(config)
+
 		# Generate resource pack
 		if config.get("assets_folder"):
 			resource_pack_main(config)
@@ -117,9 +121,9 @@ def build_process(config: dict, setup_database: Callable|None = None, setup_exte
 			recipes_main(config)
 
 		# Generate manual
-		if config.get("has_manual") == True:
+		if config.get("has_manual") is True:
 			manual_main(config)
-		
+
 		# Generate datapack
 		datapack_main(config)
 
@@ -135,7 +139,7 @@ def build_process(config: dict, setup_database: Callable|None = None, setup_exte
 
 	# Catch any exception
 	except Exception as e:
-		
+
 		# Write all files to debug
 		from .utils.io import write_all_files
 		write_all_files()
