@@ -121,5 +121,5 @@ def generate_all_iso_renders(config: dict):
 				stp.warning(f"Suggestion link: '{DOWNLOAD_VANILLA_ASSETS_SOURCE}'")
 
 	# Multithread the download
-	stp.multithreading(download_item, used_vanilla_items)
+	stp.multithreading(download_item, used_vanilla_items, max_workers=min(32, len(used_vanilla_items)))
 
