@@ -11,8 +11,20 @@ from .io import FILES_TO_WRITE
 
 
 # Function that makes an archive with consistency (same zip file each time)
-def make_archive(source: str, destination: str, copy_destinations: list[str] = []) -> float:
-	"""Make an archive with consistency using FILES_TO_WRITE variable"""
+def make_archive(source: str, destination: str, copy_destinations: list[str] | None = None) -> float:
+	""" Make an archive with consistency.
+	Creates a zip archive from a source directory, ensuring consistent file timestamps and contents.
+	Uses FILES_TO_WRITE to track known files and maintain consistency between builds.
+
+	Args:
+		source              (str):              Source directory to archive
+		destination         (str):              Path where the zip file will be created
+		copy_destinations   (list[str] | None): Optional list of additional paths to copy the archive to
+	Returns:
+		float:              Time taken to create the archive in seconds
+	"""
+	if copy_destinations is None:
+		copy_destinations = []
 	start_time: float = time.perf_counter()
 
 	# Fix copy_destinations type if needed
@@ -49,28 +61,46 @@ def make_archive(source: str, destination: str, copy_destinations: list[str] = [
 
 	# Create the archive
 	destination = destination if ".zip" in destination else destination + ".zip"
-	with ZipFile(destination, "w", compression=ZIP_DEFLATED, compresslevel=9) as zip:
 
-		# Write every not-known file with the fixed date/time
-		for file in not_known_files:
-			if source not in file:
-				continue
-			base_path: str = file.replace(source, "").strip("/")
-			info = ZipInfo(base_path)
-			info.compress_type = ZIP_DEFLATED
-			info.date_time = constant_time
+	def process_file(file: str, is_known: bool) -> tuple[ZipInfo, bytes] | None:
+		""" Process a single file for the archive.
+
+		Args:
+			file (str): Path to the file to process.
+			is_known (bool): Whether the file is in FILES_TO_WRITE.
+
+		Returns:
+			tuple[ZipInfo, bytes] | None: Tuple containing the ZipInfo and file contents, or None if file should be skipped.
+		"""
+		if source not in file:
+			return None
+
+		base_path: str = file.replace(source, "").strip("/")
+		info: ZipInfo = ZipInfo(base_path)
+		info.compress_type = ZIP_DEFLATED
+		info.date_time = constant_time
+
+		if is_known:
+			file_content = FILES_TO_WRITE[file]
+			content: bytes = file_content.encode() if isinstance(file_content, str) else file_content
+		else:
 			with open(file, "rb") as f:
-				zip.writestr(info, f.read())
-		
-		# Write every known file with the fixed date/time
-		for file in FILES_TO_WRITE:
-			if source not in file:
-				continue
-			base_path: str = file.replace(source, "").strip("/")
-			info: ZipInfo = ZipInfo(base_path)
-			info.compress_type = ZIP_DEFLATED
-			info.date_time = constant_time
-			zip.writestr(info, FILES_TO_WRITE[file])
+				content: bytes = f.read()
+
+		return info, content
+
+	# Prepare file list for processing
+	file_list: list[tuple[str, bool]] = [(f, False) for f in not_known_files] + [(f, True) for f in FILES_TO_WRITE.keys()]
+
+	# Process files in parallel
+	results: list[tuple[ZipInfo, bytes] | None] = stp.multithreading(process_file, sorted(file_list), use_starmap=True, max_workers=min(32, len(file_list)))
+
+	# Write results directly to zip file
+	with ZipFile(destination, "w", compression=ZIP_DEFLATED, compresslevel=6) as zip:
+		for result in results:
+			if result is not None:
+				info, content = result
+				zip.writestr(info, content)
 
 	# Copy the archive to the destination(s)
 	for dest_folder in copy_destinations:
@@ -79,11 +109,13 @@ def make_archive(source: str, destination: str, copy_destinations: list[str] = [
 			if dest_folder.endswith("/"):
 				file_name = destination.split("/")[-1]
 				shutil.copy(stp.clean_path(destination), f"{dest_folder}/{file_name}")
-			else:	# Else, it's not a folder but a file path
+
+			# Else, it's not a folder but a file path
+			else:
 				shutil.copy(stp.clean_path(destination), dest_folder)
 		except Exception as e:
 			stp.warning(f"Unable to copy '{stp.clean_path(destination)}' to '{dest_folder}', reason: {e}")
-	
+
 	# Return the time taken to archive the source folder
 	return time.perf_counter() - start_time
 
